@@ -193,7 +193,9 @@ class DefaultRequirements(SuiteRequirements):
     @property
     def temporary_tables(self):
         """target database supports temporary tables"""
-        return skip_if(["mssql", "firebird"], "not supported (?)")
+        return skip_if(
+            ["mssql", "firebird", self._sqlite_file_db], "not supported (?)"
+        )
 
     @property
     def temp_table_reflection(self):
@@ -317,19 +319,43 @@ class DefaultRequirements(SuiteRequirements):
     @property
     def isolation_level(self):
         return only_on(
-            ("postgresql", "sqlite", "mysql", "mssql"),
+            ("postgresql", "sqlite", "mysql", "mssql", "oracle"),
             "DBAPI has no isolation level support",
         ) + fails_on(
             "postgresql+pypostgresql",
             "pypostgresql bombs on multiple isolation level calls",
         )
 
+    def get_isolation_levels(self, config):
+        levels = set(config.db.dialect._isolation_lookup)
+
+        if against(config, "sqlite"):
+            default = "SERIALIZABLE"
+            levels.add("AUTOCOMMIT")
+        elif against(config, "postgresql"):
+            default = "READ COMMITTED"
+            levels.add("AUTOCOMMIT")
+        elif against(config, "mysql"):
+            default = "REPEATABLE READ"
+            levels.add("AUTOCOMMIT")
+        elif against(config, "mssql"):
+            default = "READ COMMITTED"
+            levels.add("AUTOCOMMIT")
+        elif against(config, "oracle"):
+            default = "READ COMMITTED"
+            levels.add("AUTOCOMMIT")
+        else:
+            raise NotImplementedError()
+
+        return {"default": default, "supported": levels}
+
     @property
     def autocommit(self):
         """target dialect supports 'AUTOCOMMIT' as an isolation_level"""
-        return only_on(
-            ("postgresql", "mysql", "mssql+pyodbc", "mssql+pymssql"),
-            "dialect does not support AUTOCOMMIT isolation mode",
+
+        return self.isolation_level + only_if(
+            lambda config: "AUTOCOMMIT"
+            in self.get_isolation_levels(config)["supported"]
         )
 
     @property
@@ -483,12 +509,14 @@ class DefaultRequirements(SuiteRequirements):
     def temp_table_names(self):
         """target dialect supports listing of temporary table names"""
 
-        return only_on(["sqlite", "oracle"])
+        return only_on(["sqlite", "oracle"]) + skip_if(self._sqlite_file_db)
 
     @property
     def temporary_views(self):
         """target database supports temporary views"""
-        return only_on(["sqlite", "postgresql"])
+        return only_on(["sqlite", "postgresql"]) + skip_if(
+            self._sqlite_file_db
+        )
 
     @property
     def update_nowait(self):
@@ -850,6 +878,16 @@ class DefaultRequirements(SuiteRequirements):
             ]
         )
 
+    def _sqlite_file_db(self, config):
+        return against(config, "sqlite") and config.db.dialect._is_url_file_db(
+            config.db.url
+        )
+
+    def _sqlite_memory_db(self, config):
+        return against(
+            config, "sqlite"
+        ) and not config.db.dialect._is_url_file_db(config.db.url)
+
     def _sqlite_json(self, config):
         if not against(config, "sqlite >= 3.9"):
             return False
@@ -1486,4 +1524,20 @@ class DefaultRequirements(SuiteRequirements):
 
     @property
     def python_profiling_backend(self):
-        return only_on(["sqlite"])
+        return only_on([self._sqlite_memory_db])
+
+    @property
+    def computed_columns_stored(self):
+        return self.computed_columns + skip_if(["oracle", "firebird"])
+
+    @property
+    def computed_columns_virtual(self):
+        return self.computed_columns + skip_if(["postgresql", "firebird"])
+
+    @property
+    def computed_columns_default_persisted(self):
+        return self.computed_columns + only_if("postgresql")
+
+    @property
+    def computed_columns_reflect_persisted(self):
+        return self.computed_columns + skip_if("oracle")
